API Reference
=============

This section of the docs describes the details of how to use each function included in pseudopeople.
These functions make up pseudopeople's public Application Programming Interface (API).
If you are a new user, you may want to start with the :ref:`Quickstart <quickstart>` guide instead.

.. toctree::
   :maxdepth: 2
   :glob:

   dataset_generation/index
   configuration/index
